@@ -21,7 +21,7 @@ fn basic_cases() {
     let cnt = 200;
 
     let hdr = {
-        let mut hdr_i = crate::Mapx::new();
+        let hdr_i = crate::Mapx::new();
 
         assert_eq!(0, hdr_i.len());
         (0..cnt).for_each(|i| {
@@ -44,7 +44,7 @@ fn basic_cases() {
         <Mapx<usize, SampleBlock> as ValueEnDe>::encode(&hdr_i)
     };
 
-    let mut reloaded = pnk!(<Mapx<usize, SampleBlock> as ValueEnDe>::decode(&hdr));
+    let reloaded = pnk!(<Mapx<usize, SampleBlock> as ValueEnDe>::decode(&hdr));
 
     assert_eq!(cnt, reloaded.len());
 
